@@ -34,14 +34,17 @@ def face_seg(img, pad=32):
     return result.astype("uint8")
 
 
-def get_face(img):
-    img = img.copy()
+def get_face(ori_img, mask=True):
+    img = ori_img.copy()
     # 获取面部分割
-    mask = face_seg(img)
-    img[np.array([mask] * img.shape[-1], dtype="uint8").transpose([1, 2, 0]) == 0] = 0
+    c_mask = face_seg(img)
+    img[np.array([c_mask] * img.shape[-1], dtype="uint8").transpose([1, 2, 0]) == 0] = 0
     # 获取外接正矩形
-    left, right, top, bottom = face_det(mask)
+    left, right, top, bottom = face_det(c_mask)
     # 裁剪
-    clip = img[top:bottom, left:right, :]
+    if mask:
+        clip = img[top:bottom, left:right, :]
+    else:
+        clip = ori_img[top:bottom, left:right, :]
     box = Box(left, right, top, bottom)
     return clip, box, mask
